import React, { useRef } from 'react';
import { CSSTransition } from 'react-transition-group';
import styles from './Dropdown.module.css';

export const Item = ({ value, onSelect, children }) => (
  <div className={styles.item} onClick={() => onSelect(value)}>
    {children}
  </div>
);

export const Dropdown = ({ open, selected, onSelect, onClick, children }) => {
  const transitionRef = useRef(null);
  return (
    <div className={styles.container}>
      <div className={styles.button} onClick={onClick}>{selected}</div>
      <CSSTransition nodeRef={transitionRef} in={open} timeout={200} mountOnEnter unmountOnExit classNames={{
        enter: styles['list-enter'],
        enterActive: styles['list-enter-active'],
        exit: styles['list-exit'],
        exitActive: styles['list-exit-active'],
      }}>
        <div className={styles.list} ref={transitionRef}>
          {children.map((child, key) => React.cloneElement(child, { onSelect, key }))}
        </div>
      </CSSTransition>
    </div>
  )
};
